@@ -590,6 +590,7 @@ class BaseCamera(TypedDict):
     hasBattery: bool
     info: CameraInformation
     type: CameraType
+    snapshotTTL: int
     activityZones: list[CameraZone]
     activitySettings: CameraActivitySettings
     frameWorkerSettings: CameraFrameWorkerSettings
@@ -680,6 +681,8 @@ class CameraDevice(Protocol):
     @property
     def type(self) -> CameraType: ...
     @property
+    def snapshot_ttl(self) -> int: ...
+    @property
     def info(self) -> CameraInformation: ...
     @property
     def is_cloud(self) -> bool: ...
